import { Box, Typography, Button, TextField, IconButton } from '@mui/material';
import ArrowBackIcon from '@mui/icons-material/ArrowBack';
import PrintIcon from '@mui/icons-material/Print';
import type { StepWithNotes } from '../types';

interface StepDetailsProps {
  step: StepWithNotes;
  onPrint: () => void;
  onAddNote: (content: string) => void;
  onBack: () => void;
}

export function StepDetails({ step, onPrint, onAddNote, onBack }: StepDetailsProps) {
  return (
    <Box sx={{ p: 2 }}>
      <Box sx={{ display: 'flex', alignItems: 'center', mb: 2 }}>
        <IconButton onClick={onBack} sx={{ mr: 1 }}>
          <ArrowBackIcon />
        </IconButton>
        <Box sx={{ display: 'flex', alignItems: 'center', gap: 1, flex: 1 }}>
          <Typography variant="h6">{step.name}</Typography>
        </Box>
        <IconButton onClick={onPrint}>
          <PrintIcon />
        </IconButton>
      </Box>
      <Typography sx={{ mb: 4 }}>{step.instructions}</Typography>

      <Box sx={{ mb: 4 }}>
        <Typography variant="h6" sx={{ mb: 2 }}>
          Notes ({step.notes.length})
        </Typography>
        {step.notes.map((note) => (
          <Box key={note.id} sx={{ mb: 2 }}>
            <Typography variant="subtitle2">{note.user?.name}</Typography>
            <Typography>{note.content}</Typography>
          </Box>
        ))}
      </Box>

      <Box sx={{ mb: 4 }}>
        <TextField
          fullWidth
          multiline
          rows={4}
          placeholder="Add a note..."
          sx={{ mb: 2 }}
        />
        <Button variant="contained" onClick={() => onAddNote('New note')}>
          Add Note
        </Button>
      </Box>
    </Box>
  );
}