import { useState, useEffect, useCallback } from 'react';

export function useAutoScreensaver(timeoutMinutes: number = 5) {
  const [isActive, setIsActive] = useState(false);
  const [lastActivity, setLastActivity] = useState(Date.now());

  const resetTimer = useCallback(() => {
    setLastActivity(Date.now());
    if (isActive) {
      setIsActive(false);
    }
  }, [isActive]);

  const activateScreensaver = useCallback(() => {
    setIsActive(true);
  }, []);

  // Track user activity
  useEffect(() => {
    const handleActivity = () => {
      resetTimer();
    };

    // Listen for various user activities
    window.addEventListener('mousemove', handleActivity);
    window.addEventListener('mousedown', handleActivity);
    window.addEventListener('keydown', handleActivity);
    window.addEventListener('touchstart', handleActivity);
    window.addEventListener('scroll', handleActivity);
    window.addEventListener('click', handleActivity);

    return () => {
      window.removeEventListener('mousemove', handleActivity);
      window.removeEventListener('mousedown', handleActivity);
      window.removeEventListener('keydown', handleActivity);
      window.removeEventListener('touchstart', handleActivity);
      window.removeEventListener('scroll', handleActivity);
      window.removeEventListener('click', handleActivity);
    };
  }, [resetTimer]);

  // Check for timeout
  useEffect(() => {
    const timeoutMs = timeoutMinutes * 60 * 1000;

    const checkTimeout = () => {
      const now = Date.now();
      if (now - lastActivity > timeoutMs && !isActive) {
        console.log(`Auto-screensaver: Activating after ${timeoutMinutes} minutes of inactivity`);
        activateScreensaver();
      }
    };

    const interval = setInterval(checkTimeout, 1000); // Check every second

    return () => clearInterval(interval);
  }, [lastActivity, isActive, timeoutMinutes, activateScreensaver]);

  return {
    isActive,
    activateScreensaver,
    resetTimer,
  };
}