import { useTaskStore } from '../stores/taskStore';
import type { GroupWithTasks } from '../types';

// Selector hooks for efficient data access
export function useGroups() {
  return useTaskStore((state) => state.groups);
}

export function useRecentTasks() {
  return useTaskStore((state) => state.recentTasks);
}

export function useFrequentTasks() {
  return useTaskStore((state) => state.frequentTasks);
}

export function useSelectedGroup() {
  return useTaskStore((state) => state.selectedGroup);
}

export function useSelectedTask() {
  return useTaskStore((state) => state.selectedTask);
}

export function useSelectedStep() {
  return useTaskStore((state) => state.selectedStep);
}

export function useLoadingStates() {
  return useTaskStore((state) => ({
    isLoadingGroups: state.isLoadingGroups,
    isLoadingRecentTasks: state.isLoadingRecentTasks,
    isLoadingFrequentTasks: state.isLoadingFrequentTasks,
    isLoadingStep: state.isLoadingStep,
  }));
}

export function useTaskActions() {
  return useTaskStore((state) => ({
    setSelectedGroup: state.setSelectedGroup,
    setSelectedTask: state.setSelectedTask,
    setSelectedStep: state.setSelectedStep,
    getTaskById: state.getTaskById,
    getStepById: state.getStepById,
    getGroupById: state.getGroupById,
  }));
}

// Custom selector for a specific task
export function useTaskById(taskId: number) {
  return useTaskStore((state) => state.getTaskById(taskId));
}

// Custom selector for a specific step
export function useStepById(stepId: number) {
  return useTaskStore((state) => state.getStepById(stepId));
}

// Custom selector for a specific group
export function useGroupById(groupId: number) {
  return useTaskStore((state) => state.getGroupById(groupId));
}

// Selector for all groups including virtual ones
export function useAllGroups() {
  return useTaskStore((state) => {
    const virtualGroups: GroupWithTasks[] = [
      {
        id: -1,
        name: 'Recent Tasks',
        created_at: new Date(),
        updated_at: new Date(),
        tasks: state.recentTasks,
      },
      {
        id: -2,
        name: 'Frequent Tasks',
        created_at: new Date(),
        updated_at: new Date(),
        tasks: state.frequentTasks,
      },
    ];
    return [...virtualGroups, ...state.groups];
  });
}